# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/api_user/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/api_user/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.api_user.v1 import api_user_pb2 as meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'meshtrade/iam/api_user/v1/service.proto\x12\x19meshtrade.iam.api_user.v1\x1a\x1b\x62uf/validate/validate.proto\x1a(meshtrade/iam/api_user/v1/api_user.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\"h\n\x11GetApiUserRequest\x12S\n\x04name\x18\x01 \x01(\tB?\xbaH<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01$\xc8\x01\x01R\x04name\"Z\n\x1aGetApiUserByKeyHashRequest\x12<\n\x08key_hash\x18\x01 \x01(\tB!\xbaH\x1er\x19\x32\x14^[A-Za-z0-9+/]{43}=$\x98\x01,\xc8\x01\x01R\x07keyHash\"]\n\x14\x43reateApiUserRequest\x12\x45\n\x08\x61pi_user\x18\x01 \x01(\x0b\x32\".meshtrade.iam.api_user.v1.APIUserB\x06\xbaH\x03\xc8\x01\x01R\x07\x61piUser\"\xe2\x01\n\x1b\x41ssignRolesToAPIUserRequest\x12S\n\x04name\x18\x01 \x01(\tB?\xbaH<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01$\xc8\x01\x01R\x04name\x12n\n\x05roles\x18\x02 \x03(\tBX\xbaHU\x92\x01O\"MrK\x10/\x18\x30\x32\x45^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$\xc8\x01\x01R\x05roles\"\xe4\x01\n\x1dRevokeRolesFromAPIUserRequest\x12S\n\x04name\x18\x01 \x01(\tB?\xbaH<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01$\xc8\x01\x01R\x04name\x12n\n\x05roles\x18\x02 \x03(\tBX\xbaHU\x92\x01O\"MrK\x10/\x18\x30\x32\x45^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$\xc8\x01\x01R\x05roles\"\x15\n\x13ListApiUsersRequest\"W\n\x14ListApiUsersResponse\x12?\n\tapi_users\x18\x01 \x03(\x0b\x32\".meshtrade.iam.api_user.v1.APIUserR\x08\x61piUsers\":\n\x15SearchApiUsersRequest\x12!\n\x0c\x64isplay_name\x18\x01 \x01(\tR\x0b\x64isplayName\"Y\n\x16SearchApiUsersResponse\x12?\n\tapi_users\x18\x01 \x03(\x0b\x32\".meshtrade.iam.api_user.v1.APIUserR\x08\x61piUsers\"m\n\x16\x41\x63tivateApiUserRequest\x12S\n\x04name\x18\x01 \x01(\tB?\xbaH<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01$\xc8\x01\x01R\x04name\"o\n\x18\x44\x65\x61\x63tivateApiUserRequest\x12S\n\x04name\x18\x01 \x01(\tB?\xbaH<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01$\xc8\x01\x01R\x04name2\xce\t\n\x0e\x41piUserService\x12z\n\nGetApiUser\x12,.meshtrade.iam.api_user.v1.GetApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc2\x8d\xb7\x01\xc3\x8d\xb7\x01\x12x\n\rCreateApiUser\x12/.meshtrade.iam.api_user.v1.CreateApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x12\xa0\xb5\x18\x02\xaa\xb5\x18\n\n\x08\xc0\x8d\xb7\x01\xc2\x8d\xb7\x01\x12\x86\x01\n\x14\x41ssignRolesToAPIUser\x12\x36.meshtrade.iam.api_user.v1.AssignRolesToAPIUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x12\xa0\xb5\x18\x02\xaa\xb5\x18\n\n\x08\xc0\x8d\xb7\x01\xc2\x8d\xb7\x01\x12\x8a\x01\n\x16RevokeRolesFromAPIUser\x12\x38.meshtrade.iam.api_user.v1.RevokeRolesFromAPIUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x12\xa0\xb5\x18\x02\xaa\xb5\x18\n\n\x08\xc0\x8d\xb7\x01\xc2\x8d\xb7\x01\x12\x8b\x01\n\x0cListApiUsers\x12..meshtrade.iam.api_user.v1.ListApiUsersRequest\x1a/.meshtrade.iam.api_user.v1.ListApiUsersResponse\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc2\x8d\xb7\x01\xc3\x8d\xb7\x01\x12\x91\x01\n\x0eSearchApiUsers\x12\x30.meshtrade.iam.api_user.v1.SearchApiUsersRequest\x1a\x31.meshtrade.iam.api_user.v1.SearchApiUsersResponse\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc2\x8d\xb7\x01\xc3\x8d\xb7\x01\x12|\n\x0f\x41\x63tivateApiUser\x12\x31.meshtrade.iam.api_user.v1.ActivateApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x12\xa0\xb5\x18\x02\xaa\xb5\x18\n\n\x08\xc0\x8d\xb7\x01\xc2\x8d\xb7\x01\x12\x80\x01\n\x11\x44\x65\x61\x63tivateApiUser\x12\x33.meshtrade.iam.api_user.v1.DeactivateApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x12\xa0\xb5\x18\x02\xaa\xb5\x18\n\n\x08\xc0\x8d\xb7\x01\xc2\x8d\xb7\x01\x12\x8c\x01\n\x13GetApiUserByKeyHash\x12\x35.meshtrade.iam.api_user.v1.GetApiUserByKeyHashRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc2\x8d\xb7\x01\xc3\x8d\xb7\x01\x42[\n co.meshtrade.api.iam.api_user.v1Z7github.com/meshtrade/api/go/iam/api_user/v1;api_user_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.api_user.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n co.meshtrade.api.iam.api_user.v1Z7github.com/meshtrade/api/go/iam/api_user/v1;api_user_v1'
  _globals['_GETAPIUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETAPIUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001$\310\001\001'
  _globals['_GETAPIUSERBYKEYHASHREQUEST'].fields_by_name['key_hash']._loaded_options = None
  _globals['_GETAPIUSERBYKEYHASHREQUEST'].fields_by_name['key_hash']._serialized_options = b'\272H\036r\0312\024^[A-Za-z0-9+/]{43}=$\230\001,\310\001\001'
  _globals['_CREATEAPIUSERREQUEST'].fields_by_name['api_user']._loaded_options = None
  _globals['_CREATEAPIUSERREQUEST'].fields_by_name['api_user']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ASSIGNROLESTOAPIUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_ASSIGNROLESTOAPIUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001$\310\001\001'
  _globals['_ASSIGNROLESTOAPIUSERREQUEST'].fields_by_name['roles']._loaded_options = None
  _globals['_ASSIGNROLESTOAPIUSERREQUEST'].fields_by_name['roles']._serialized_options = b'\272HU\222\001O\"MrK\020/\03002E^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$\310\001\001'
  _globals['_REVOKEROLESFROMAPIUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REVOKEROLESFROMAPIUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001$\310\001\001'
  _globals['_REVOKEROLESFROMAPIUSERREQUEST'].fields_by_name['roles']._loaded_options = None
  _globals['_REVOKEROLESFROMAPIUSERREQUEST'].fields_by_name['roles']._serialized_options = b'\272HU\222\001O\"MrK\020/\03002E^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$\310\001\001'
  _globals['_ACTIVATEAPIUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_ACTIVATEAPIUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001$\310\001\001'
  _globals['_DEACTIVATEAPIUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DEACTIVATEAPIUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H<r722^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001$\310\001\001'
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUser']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\215\267\001\301\215\267\001\302\215\267\001\303\215\267\001'
  _globals['_APIUSERSERVICE'].methods_by_name['CreateApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['CreateApiUser']._serialized_options = b'\240\265\030\002\252\265\030\n\n\010\300\215\267\001\302\215\267\001'
  _globals['_APIUSERSERVICE'].methods_by_name['AssignRolesToAPIUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['AssignRolesToAPIUser']._serialized_options = b'\240\265\030\002\252\265\030\n\n\010\300\215\267\001\302\215\267\001'
  _globals['_APIUSERSERVICE'].methods_by_name['RevokeRolesFromAPIUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['RevokeRolesFromAPIUser']._serialized_options = b'\240\265\030\002\252\265\030\n\n\010\300\215\267\001\302\215\267\001'
  _globals['_APIUSERSERVICE'].methods_by_name['ListApiUsers']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['ListApiUsers']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\215\267\001\301\215\267\001\302\215\267\001\303\215\267\001'
  _globals['_APIUSERSERVICE'].methods_by_name['SearchApiUsers']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['SearchApiUsers']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\215\267\001\301\215\267\001\302\215\267\001\303\215\267\001'
  _globals['_APIUSERSERVICE'].methods_by_name['ActivateApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['ActivateApiUser']._serialized_options = b'\240\265\030\002\252\265\030\n\n\010\300\215\267\001\302\215\267\001'
  _globals['_APIUSERSERVICE'].methods_by_name['DeactivateApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['DeactivateApiUser']._serialized_options = b'\240\265\030\002\252\265\030\n\n\010\300\215\267\001\302\215\267\001'
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUserByKeyHash']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUserByKeyHash']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\215\267\001\301\215\267\001\302\215\267\001\303\215\267\001'
  _globals['_GETAPIUSERREQUEST']._serialized_start=214
  _globals['_GETAPIUSERREQUEST']._serialized_end=318
  _globals['_GETAPIUSERBYKEYHASHREQUEST']._serialized_start=320
  _globals['_GETAPIUSERBYKEYHASHREQUEST']._serialized_end=410
  _globals['_CREATEAPIUSERREQUEST']._serialized_start=412
  _globals['_CREATEAPIUSERREQUEST']._serialized_end=505
  _globals['_ASSIGNROLESTOAPIUSERREQUEST']._serialized_start=508
  _globals['_ASSIGNROLESTOAPIUSERREQUEST']._serialized_end=734
  _globals['_REVOKEROLESFROMAPIUSERREQUEST']._serialized_start=737
  _globals['_REVOKEROLESFROMAPIUSERREQUEST']._serialized_end=965
  _globals['_LISTAPIUSERSREQUEST']._serialized_start=967
  _globals['_LISTAPIUSERSREQUEST']._serialized_end=988
  _globals['_LISTAPIUSERSRESPONSE']._serialized_start=990
  _globals['_LISTAPIUSERSRESPONSE']._serialized_end=1077
  _globals['_SEARCHAPIUSERSREQUEST']._serialized_start=1079
  _globals['_SEARCHAPIUSERSREQUEST']._serialized_end=1137
  _globals['_SEARCHAPIUSERSRESPONSE']._serialized_start=1139
  _globals['_SEARCHAPIUSERSRESPONSE']._serialized_end=1228
  _globals['_ACTIVATEAPIUSERREQUEST']._serialized_start=1230
  _globals['_ACTIVATEAPIUSERREQUEST']._serialized_end=1339
  _globals['_DEACTIVATEAPIUSERREQUEST']._serialized_start=1341
  _globals['_DEACTIVATEAPIUSERREQUEST']._serialized_end=1452
  _globals['_APIUSERSERVICE']._serialized_start=1455
  _globals['_APIUSERSERVICE']._serialized_end=2685
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.iam.user.v1 import service_pb2 as meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2
from meshtrade.iam.user.v1 import user_pb2 as meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2


class UserServiceStub(object):
    """
    UserService manages user lifecycle and identity operations within groups.

    Users are individual identity entities that belong to specific groups and have
    assigned roles that determine their permissions within that group context.
    Each user has a unique email address and can be assigned multiple roles
    across the group hierarchy for fine-grained access control.

    All operations require appropriate IAM domain permissions and operate within
    the authenticated group context.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AssignRolesToUser = channel.unary_unary(
                '/meshtrade.iam.user.v1.UserService/AssignRolesToUser',
                request_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.AssignRolesToUserRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
                _registered_method=True)
        self.RevokeRolesFromUser = channel.unary_unary(
                '/meshtrade.iam.user.v1.UserService/RevokeRolesFromUser',
                request_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.RevokeRolesFromUserRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
                _registered_method=True)
        self.GetUser = channel.unary_unary(
                '/meshtrade.iam.user.v1.UserService/GetUser',
                request_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.GetUserRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
                _registered_method=True)
        self.ListUsers = channel.unary_unary(
                '/meshtrade.iam.user.v1.UserService/ListUsers',
                request_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.ListUsersResponse.FromString,
                _registered_method=True)
        self.SearchUsers = channel.unary_unary(
                '/meshtrade.iam.user.v1.UserService/SearchUsers',
                request_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.SearchUsersRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.SearchUsersResponse.FromString,
                _registered_method=True)
        self.CreateUser = channel.unary_unary(
                '/meshtrade.iam.user.v1.UserService/CreateUser',
                request_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
                _registered_method=True)
        self.UpdateUser = channel.unary_unary(
                '/meshtrade.iam.user.v1.UserService/UpdateUser',
                request_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
                _registered_method=True)


class UserServiceServicer(object):
    """
    UserService manages user lifecycle and identity operations within groups.

    Users are individual identity entities that belong to specific groups and have
    assigned roles that determine their permissions within that group context.
    Each user has a unique email address and can be assigned multiple roles
    across the group hierarchy for fine-grained access control.

    All operations require appropriate IAM domain permissions and operate within
    the authenticated group context.
    """

    def AssignRolesToUser(self, request, context):
        """
        Assign roles to an existing user within the authenticated group context.

        The role assignment enables the user to perform operations according
        to the permissions associated with that role within the group hierarchy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeRolesFromUser(self, request, context):
        """
        Revoke roles from an existing user within the authenticated group context.

        The role revocation removes the permissions associated with that role from
        the user within the group hierarchy. The user will no longer be able
        to perform operations that require the revoked role.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """
        Retrieves a single user by its unique identifier.

        Returns user details including name, email, ownership information,
        and assigned roles within the authenticated group's access scope.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """
        Returns all users accessible within the authenticated group's hierarchy.

        Results include users directly owned and those accessible through the
        group's hierarchical permissions, optionally sorted by email address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchUsers(self, request, context):
        """
        Searches for users by email address using substring matching.

        Returns users whose email addresses contain the provided search term,
        filtered by the authenticated group's access permissions and optionally
        sorted by email address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUser(self, request, context):
        """
        Creates a new user within the authenticated group context.

        The user will be created with the provided email and group ownership,
        with system-generated unique identifier and ownership hierarchy.
        Additional roles can be assigned after creation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        """
        Updates an existing user with modified field values.

        Only mutable fields can be updated while preserving system-generated
        identifiers and ownership relationships. Role modifications should
        use dedicated role management operations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AssignRolesToUser': grpc.unary_unary_rpc_method_handler(
                    servicer.AssignRolesToUser,
                    request_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.AssignRolesToUserRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.SerializeToString,
            ),
            'RevokeRolesFromUser': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeRolesFromUser,
                    request_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.RevokeRolesFromUserRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.GetUserRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.ListUsersRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.ListUsersResponse.SerializeToString,
            ),
            'SearchUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchUsers,
                    request_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.SearchUsersRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.SearchUsersResponse.SerializeToString,
            ),
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.CreateUserRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.SerializeToString,
            ),
            'UpdateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUser,
                    request_deserializer=meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.UpdateUserRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.iam.user.v1.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.iam.user.v1.UserService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """
    UserService manages user lifecycle and identity operations within groups.

    Users are individual identity entities that belong to specific groups and have
    assigned roles that determine their permissions within that group context.
    Each user has a unique email address and can be assigned multiple roles
    across the group hierarchy for fine-grained access control.

    All operations require appropriate IAM domain permissions and operate within
    the authenticated group context.
    """

    @staticmethod
    def AssignRolesToUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.user.v1.UserService/AssignRolesToUser',
            meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.AssignRolesToUserRequest.SerializeToString,
            meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RevokeRolesFromUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.user.v1.UserService/RevokeRolesFromUser',
            meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.RevokeRolesFromUserRequest.SerializeToString,
            meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.user.v1.UserService/GetUser',
            meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.GetUserRequest.SerializeToString,
            meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.user.v1.UserService/ListUsers',
            meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.ListUsersRequest.SerializeToString,
            meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.ListUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.user.v1.UserService/SearchUsers',
            meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.SearchUsersRequest.SerializeToString,
            meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.SearchUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.user.v1.UserService/CreateUser',
            meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.CreateUserRequest.SerializeToString,
            meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.user.v1.UserService/UpdateUser',
            meshtrade_dot_iam_dot_user_dot_v1_dot_service__pb2.UpdateUserRequest.SerializeToString,
            meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class APICredentials(_message.Message):
    __slots__ = ("api_key", "group")
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    api_key: str
    group: str
    def __init__(self, api_key: _Optional[str] = ..., group: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/account_report/v1/account_report.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/account_report/v1/account_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2
from meshtrade.type.v1 import address_pb2 as meshtrade_dot_type_dot_v1_dot_address__pb2
from meshtrade.reporting.account_report.v1 import fee_entry_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_fee__entry__pb2
from meshtrade.reporting.account_report.v1 import income_entry_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_income__entry__pb2
from meshtrade.reporting.account_report.v1 import trading_statement_entry_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_trading__statement__entry__pb2
from meshtrade.reporting.account_report.v1 import disclaimer_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_disclaimer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:meshtrade/reporting/account_report/v1/account_report.proto\x12%meshtrade.reporting.account_report.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dmeshtrade/type/v1/token.proto\x1a\x1fmeshtrade/type/v1/address.proto\x1a\x35meshtrade/reporting/account_report/v1/fee_entry.proto\x1a\x38meshtrade/reporting/account_report/v1/income_entry.proto\x1a\x43meshtrade/reporting/account_report/v1/trading_statement_entry.proto\x1a\x36meshtrade/reporting/account_report/v1/disclaimer.proto\"\x9c\x07\n\rAccountReport\x12Y\n\x0eincome_entries\x18\x01 \x03(\x0b\x32\x32.meshtrade.reporting.account_report.v1.IncomeEntryR\rincomeEntries\x12P\n\x0b\x66\x65\x65_entries\x18\x02 \x03(\x0b\x32/.meshtrade.reporting.account_report.v1.FeeEntryR\nfeeEntries\x12x\n\x19trading_statement_entries\x18\x03 \x03(\x0b\x32<.meshtrade.reporting.account_report.v1.TradingStatementEntryR\x17tradingStatementEntries\x12G\n\x12reporting_currency\x18\x04 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x11reportingCurrency\x12S\n\x06period\x18\x05 \x01(\x0b\x32;.meshtrade.reporting.account_report.v1.AccountReport.PeriodR\x06period\x12\x43\n\x0fgeneration_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0egenerationDate\x12%\n\x0e\x61\x63\x63ount_number\x18\x07 \x01(\tR\raccountNumber\x12S\n\x0b\x64isclaimers\x18\x08 \x03(\x0b\x32\x31.meshtrade.reporting.account_report.v1.DisclaimerR\x0b\x64isclaimers\x12\x41\n\x0e\x63lient_address\x18\t \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\rclientAddress\x12\x1f\n\x0b\x63lient_name\x18\n \x01(\tR\nclientName\x12\x1c\n\tcopyright\x18\x0b \x01(\tR\tcopyright\x1a\x82\x01\n\x06Period\x12=\n\x0cperiod_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bperiodStart\x12\x39\n\nperiod_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tperiodEndBy\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.account_report.v1.account_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1'
  _globals['_ACCOUNTREPORT']._serialized_start=437
  _globals['_ACCOUNTREPORT']._serialized_end=1361
  _globals['_ACCOUNTREPORT_PERIOD']._serialized_start=1231
  _globals['_ACCOUNTREPORT_PERIOD']._serialized_end=1361
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/trading/limit_order/v1/limit_order.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/trading/limit_order/v1/limit_order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/trading/limit_order/v1/limit_order.proto\x12 meshtrade.trading.limit_order.v1\"$\n\nLimitOrder\x12\x16\n\x06number\x18\x01 \x01(\tR\x06numberBl\n\'co.meshtrade.api.trading.limit_order.v1ZAgithub.com/meshtrade/api/go/trading/limit_order/v1;limit_order_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.trading.limit_order.v1.limit_order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'co.meshtrade.api.trading.limit_order.v1ZAgithub.com/meshtrade/api/go/trading/limit_order/v1;limit_order_v1'
  _globals['_LIMITORDER']._serialized_start=88
  _globals['_LIMITORDER']._serialized_end=124
# @@protoc_insertion_point(module_scope)



import datetime

from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from meshtrade.compliance.client.v1 import company_pb2 as _company_pb2
from meshtrade.iam.role.v1 import role_pb2 as _role_pb2
from meshtrade.compliance.client.v1 import fund_pb2 as _fund_pb2
from meshtrade.compliance.client.v1 import natural_person_pb2 as _natural_person_pb2
from meshtrade.compliance.client.v1 import trust_pb2 as _trust_pb2
from meshtrade.compliance.client.v1 import verification_status_pb2 as _verification_status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Client(_message.Message):
    __slots__ = ("name", "owner", "display_name", "natural_person", "company", "fund", "trust", "verification_status", "verification_authority", "verification_date", "next_verification_date", "roles")
    NAME_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    NATURAL_PERSON_FIELD_NUMBER: _ClassVar[int]
    COMPANY_FIELD_NUMBER: _ClassVar[int]
    FUND_FIELD_NUMBER: _ClassVar[int]
    TRUST_FIELD_NUMBER: _ClassVar[int]
    VERIFICATION_STATUS_FIELD_NUMBER: _ClassVar[int]
    VERIFICATION_AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    VERIFICATION_DATE_FIELD_NUMBER: _ClassVar[int]
    NEXT_VERIFICATION_DATE_FIELD_NUMBER: _ClassVar[int]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    name: str
    owner: str
    display_name: str
    natural_person: _natural_person_pb2.NaturalPerson
    company: _company_pb2.Company
    fund: _fund_pb2.Fund
    trust: _trust_pb2.Trust
    verification_status: _verification_status_pb2.VerificationStatus
    verification_authority: str
    verification_date: _timestamp_pb2.Timestamp
    next_verification_date: _timestamp_pb2.Timestamp
    roles: _containers.RepeatedScalarFieldContainer[_role_pb2.Role]
    def __init__(self, name: _Optional[str] = ..., owner: _Optional[str] = ..., display_name: _Optional[str] = ..., natural_person: _Optional[_Union[_natural_person_pb2.NaturalPerson, _Mapping]] = ..., company: _Optional[_Union[_company_pb2.Company, _Mapping]] = ..., fund: _Optional[_Union[_fund_pb2.Fund, _Mapping]] = ..., trust: _Optional[_Union[_trust_pb2.Trust, _Mapping]] = ..., verification_status: _Optional[_Union[_verification_status_pb2.VerificationStatus, str]] = ..., verification_authority: _Optional[str] = ..., verification_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., next_verification_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., roles: _Optional[_Iterable[_Union[_role_pb2.Role, str]]] = ...) -> None: ...



"""Amount utility functions for Mesh API.

This module provides utility functions for working with Amount protobuf messages,
including creation, validation, comparison, and arithmetic operations.
"""

from decimal import ROUND_DOWN
from decimal import Decimal as PyDecimal

from .amount_pb2 import Amount
from .decimal_built_in_conversions import built_in_to_decimal, decimal_to_built_in
from .decimal_pb2 import Decimal
from .ledger import get_ledger_no_decimal_places
from .token import new_undefined_token
from .token_pb2 import Token


def new_amount(value: PyDecimal, token: Token, precision_loss_tolerance: PyDecimal = PyDecimal("0.00000001")) -> Amount:
    """Creates a new Amount, ensuring the value conforms to system-wide limits.

    This function is the safe constructor for creating Amount protobuf messages.
    While the underlying conversion from a Python `Decimal` to the protobuf's
    `string` field is lossless, this function provides critical validation
    to ensure the value adheres to constraints imposed by other downstream
    systems (e.g., databases, other microservices with fixed-precision types).

    Its primary operations are:

    1.  **Validation:** It performs a serialization round-trip
        (Python Decimal -> Protobuf Decimal -> Python Decimal) to simulate
        how the value is stored and retrieved across the system. It then asserts
        the value remains unchanged, guaranteeing it doesn't exceed the
        precision limits of any consuming service.

    2.  **Truncation:** It truncates the validated value to the exact number of
        decimal places defined for the token's ledger, always rounding down to
        prevent any inflation of values.

    3.  **Construction:** It constructs and returns the final `Amount` message.

    Args:
        value: The numerical value of the amount as a Python `Decimal` object.
        token: The `Token` protobuf message that defines the asset type
               and its associated ledger.
        precision_loss_tolerance: The maximum acceptable difference after the
            validation round-trip. Since the string-based conversion is
            lossless, any difference indicates a failure to conform to an
            external system's parsing rules. Defaults to a small tolerance
            for robustness.

    Returns:
        An `Amount` protobuf message containing the ledger-compliant, truncated
        value and the specified token.

    Raises:
        AssertionError: If the input `value` changes during the validation
                        round-trip, indicating it exceeds the system's
                        representational limits and would be corrupted
                        downstream.
    """

    # Perform a serialization round-trip to validate the value against
    # system-wide architectural constraints. This is a lossless operation
    # in isolation, so any change reveals an incompatibility.
    value_after_roundtrip = decimal_to_built_in(built_in_to_decimal(value))

    # Confirm the value is perfectly representable within the system's limits.
    # If the original value had too much precision for a downstream service to
    # parse, it would change during the round-trip, and this would fail.
    assert abs(value_after_roundtrip - value) <= precision_loss_tolerance, "value exceeds system's precision limits and would be corrupted"

    # Truncate the validated value to the number of decimal places specified by the
    # token's ledger. ROUND_DOWN ensures the value is never inflated.
    truncated_value = value_after_roundtrip.quantize(
        PyDecimal(10) ** -get_ledger_no_decimal_places(token.ledger),
        rounding=ROUND_DOWN,
    )

    # Construct and return the final Amount protobuf message using the sanitized value.
    return Amount(
        token=token,
        value=built_in_to_decimal(truncated_value),
    )


def new_undefined_amount(value: PyDecimal) -> Amount:
    """Create a new Amount with the specified value and an undefined token.

    This is useful as a placeholder or when the token type is not yet known.
    Since undefined tokens don't have a valid ledger, this bypasses ledger
    validation and creates the amount directly with full precision.

    Args:
        value: The decimal value for the amount

    Returns:
        A new Amount with the specified value and an undefined token

    Example:
        >>> from decimal import Decimal as PyDecimal
        >>> amount = new_undefined_amount(PyDecimal("100"))
        >>> amount_is_undefined(amount)
        True
    """
    # Undefined tokens don't have a valid ledger, so we create the Amount directly
    # without going through new_amount() which requires ledger validation
    return Amount(
        value=built_in_to_decimal(value),
        token=new_undefined_token(),
    )


def amount_set_value(
    amount: Amount,
    value: PyDecimal,
    precision_loss_tolerance: PyDecimal = PyDecimal("0.00000001"),
) -> Amount:
    """Create a new Amount with the given value and the same token as the input amount.

    Despite its name, this function does NOT modify the input - it creates and returns a NEW Amount.

    Args:
        amount: The amount whose token to use
        value: The decimal value for the new amount
        precision_loss_tolerance: The maximum acceptable difference after validation
            round-trip. Defaults to a small tolerance for robustness.

    Returns:
        A new Amount with the specified value and the same token

    Raises:
        ValueError: If amount is None
        AssertionError: If the value exceeds system precision limits

    Example:
        >>> from decimal import Decimal as PyDecimal
        >>> original = new_undefined_amount(PyDecimal("100"))
        >>> modified = amount_set_value(original, PyDecimal("200"))
        >>> # original is unchanged, modified is a new Amount with value 200
    """
    if amount is None:
        raise ValueError("amount cannot be None")

    # Check if the token is undefined (doesn't have a valid ledger)
    from .token import token_is_undefined

    if token_is_undefined(amount.token):
        # For undefined tokens, create Amount directly without ledger validation
        return Amount(
            value=built_in_to_decimal(value),
            token=amount.token,
        )

    return new_amount(value, amount.token, precision_loss_tolerance)


def amount_is_undefined(amount: Amount | None) -> bool:
    """Check whether this amount has an undefined token.

    An amount is considered undefined if its associated token is undefined.

    Args:
        amount: Amount to check (can be None)

    Returns:
        True if the amount's token is undefined or if amount is None, False otherwise

    None Safety:
        Returns True if amount is None

    Example:
        >>> amount = new_undefined_amount(PyDecimal("100"))
        >>> amount_is_undefined(amount)
        True
    """
    if amount is None:
        return True

    from .token import token_is_undefined

    return token_is_undefined(amount.token)


def amount_is_same_type_as(amount1: Amount | None, amount2: Amount | None) -> bool:
    """Check if two amounts have the same token type (same currency/asset).

    This is useful for validating that amounts can be compared or combined arithmetically.

    Args:
        amount1: First amount (can be None)
        amount2: Second amount (can be None)

    Returns:
        True if both amounts have equal tokens, False otherwise

    None Safety:
        Returns False if either amount is None

    Example:
        >>> usd_amount1 = new_undefined_amount(PyDecimal("100"))
        >>> usd_amount2 = new_undefined_amount(PyDecimal("200"))
        >>> amount_is_same_type_as(usd_amount1, usd_amount2)
        True
    """
    if amount1 is None or amount2 is None:
        return False

    from .token import token_is_equal_to

    return token_is_equal_to(amount1.token, amount2.token)


def amount_is_equal_to(amount1: Amount | None, amount2: Amount | None) -> bool:
    """Check if two amounts are equal in both value and token type.

    Two amounts are considered equal if they have the same decimal value AND the same token.

    Args:
        amount1: First amount (can be None)
        amount2: Second amount (can be None)

    Returns:
        True if both amounts have equal values and tokens (or both are None), False otherwise

    None Safety:
        Returns True if both are None, False if only one is None

    Example:
        >>> amount1 = new_undefined_amount(PyDecimal("100"))
        >>> amount2 = new_undefined_amount(PyDecimal("100"))
        >>> amount_is_equal_to(amount1, amount2)
        True
    """
    if amount1 is None and amount2 is None:
        return True
    if amount1 is None or amount2 is None:
        return False

    from .decimal_operations import decimal_equal
    from .token import token_is_equal_to

    return token_is_equal_to(amount1.token, amount2.token) and decimal_equal(amount1.value, amount2.value)


def amount_is_negative(amount: Amount | None) -> bool:
    """Check whether the amount's value is less than zero.

    Args:
        amount: Amount to check (can be None)

    Returns:
        True if the value is negative (< 0), False otherwise

    None Safety:
        Returns False if amount is None

    Example:
        >>> amount = new_undefined_amount(PyDecimal("-50"))
        >>> amount_is_negative(amount)
        True
    """
    if amount is None:
        return False

    from .decimal_operations import decimal_is_negative

    return decimal_is_negative(amount.value)


def amount_is_zero(amount: Amount | None) -> bool:
    """Check whether the amount's value is exactly zero.

    Args:
        amount: Amount to check (can be None)

    Returns:
        True if the value is zero, False otherwise

    None Safety:
        Returns False if amount is None

    Example:
        >>> amount = new_undefined_amount(PyDecimal("0"))
        >>> amount_is_zero(amount)
        True
    """
    if amount is None:
        return False

    from .decimal_operations import decimal_is_zero

    return decimal_is_zero(amount.value)


def amount_contains_fractions(amount: Amount | None) -> bool:
    """Check whether the amount's value has any fractional (decimal) component.

    This is useful for determining if an amount can be represented as a whole number.

    Args:
        amount: Amount to check (can be None)

    Returns:
        True if the value has fractional/decimal places, False otherwise

    None Safety:
        Returns False if amount is None

    Example:
        >>> amount1 = new_undefined_amount(PyDecimal("100.50"))
        >>> amount_contains_fractions(amount1)
        True
        >>> amount2 = new_undefined_amount(PyDecimal("100"))
        >>> amount_contains_fractions(amount2)
        False
    """
    if amount is None:
        return False

    # Convert protobuf Decimal to Python Decimal
    value = PyDecimal(amount.value.value) if amount.value and amount.value.value else PyDecimal(0)

    # Check if truncating to 0 decimal places changes the value
    return value.quantize(PyDecimal("1"), rounding=ROUND_DOWN) != value


def amount_add(
    amount1: Amount,
    amount2: Amount,
    precision_loss_tolerance: PyDecimal = PyDecimal("0.00000001"),
) -> Amount:
    """Add two amounts and return a new amount with the result.

    The amounts must have the same token type (currency/asset).

    Args:
        amount1: First amount
        amount2: Second amount (must have same token as amount1)
        precision_loss_tolerance: The maximum acceptable difference after validation
            round-trip. Defaults to a small tolerance for robustness.

    Returns:
        A new Amount containing the sum (amount1 + amount2)

    Raises:
        ValueError: If either amount is None or if the amounts have different token types
        AssertionError: If the result exceeds system precision limits

    Example:
        >>> amount1 = new_undefined_amount(PyDecimal("100"))
        >>> amount2 = new_undefined_amount(PyDecimal("30"))
        >>> result = amount_add(amount1, amount2)
        >>> # result value is 130
    """
    if amount1 is None:
        raise ValueError("amount1 cannot be None")
    if amount2 is None:
        raise ValueError("amount2 cannot be None")

    from .decimal_operations import decimal_add
    from .token import token_is_equal_to, token_pretty_string

    if not token_is_equal_to(amount1.token, amount2.token):
        raise ValueError(
            f"cannot do arithmetic on amounts of different token denominations: "
            f"{token_pretty_string(amount1.token)} vs. {token_pretty_string(amount2.token)}"
        )

    new_value_decimal = decimal_add(amount1.value, amount2.value)
    new_value_py = PyDecimal(new_value_decimal.value) if new_value_decimal.value else PyDecimal(0)

    return amount_set_value(amount1, new_value_py, precision_loss_tolerance)


def amount_sub(
    amount1: Amount,
    amount2: Amount,
    precision_loss_tolerance: PyDecimal = PyDecimal("0.00000001"),
) -> Amount:
    """Subtract amount2 from amount1 and return a new amount with the result.

    The amounts must have the same token type (currency/asset).

    Args:
        amount1: First amount
        amount2: Second amount to subtract (must have same token as amount1)
        precision_loss_tolerance: The maximum acceptable difference after validation
            round-trip. Defaults to a small tolerance for robustness.

    Returns:
        A new Amount containing the difference (amount1 - amount2)

    Raises:
        ValueError: If either amount is None or if the amounts have different token types
        AssertionError: If the result exceeds system precision limits

    Example:
        >>> amount1 = new_undefined_amount(PyDecimal("100"))
        >>> amount2 = new_undefined_amount(PyDecimal("30"))
        >>> result = amount_sub(amount1, amount2)
        >>> # result value is 70
    """
    if amount1 is None:
        raise ValueError("amount1 cannot be None")
    if amount2 is None:
        raise ValueError("amount2 cannot be None")

    from .decimal_operations import decimal_sub
    from .token import token_is_equal_to, token_pretty_string

    if not token_is_equal_to(amount1.token, amount2.token):
        raise ValueError(
            f"cannot do arithmetic on amounts of different token denominations: "
            f"{token_pretty_string(amount1.token)} vs. {token_pretty_string(amount2.token)}"
        )

    new_value_decimal = decimal_sub(amount1.value, amount2.value)
    new_value_py = PyDecimal(new_value_decimal.value) if new_value_decimal.value else PyDecimal(0)

    return amount_set_value(amount1, new_value_py, precision_loss_tolerance)


def amount_decimal_mul(
    amount: Amount,
    multiplier: PyDecimal,
    precision_loss_tolerance: PyDecimal = PyDecimal("0.00000001"),
) -> Amount:
    """Multiply this amount by a decimal value and return a new amount with the result.

    The token type is preserved.

    Args:
        amount: The amount to multiply
        multiplier: The decimal multiplier
        precision_loss_tolerance: The maximum acceptable difference after validation
            round-trip. Defaults to a small tolerance for robustness.

    Returns:
        A new Amount containing the product (amount * multiplier)

    Raises:
        ValueError: If amount is None
        AssertionError: If the result exceeds system precision limits

    Example:
        >>> amount = new_undefined_amount(PyDecimal("100"))
        >>> result = amount_decimal_mul(amount, PyDecimal("2"))
        >>> # result value is 200
    """
    if amount is None:
        raise ValueError("amount cannot be None")

    from .decimal_operations import decimal_mul

    multiplier_decimal = Decimal(value=str(multiplier))
    new_value_decimal = decimal_mul(amount.value, multiplier_decimal)
    new_value_py = PyDecimal(new_value_decimal.value) if new_value_decimal.value else PyDecimal(0)

    return amount_set_value(amount, new_value_py, precision_loss_tolerance)


def amount_decimal_div(
    amount: Amount,
    divisor: PyDecimal,
    precision_loss_tolerance: PyDecimal = PyDecimal("0.00000001"),
) -> Amount:
    """Divide this amount by a decimal value and return a new amount with the result.

    The token type is preserved.

    Args:
        amount: The amount to divide
        divisor: The decimal divisor (must not be zero)
        precision_loss_tolerance: The maximum acceptable difference after validation
            round-trip. Defaults to a small tolerance for robustness.

    Returns:
        A new Amount containing the quotient (amount / divisor)

    Raises:
        ValueError: If amount is None
        ZeroDivisionError: If divisor is zero
        AssertionError: If the result exceeds system precision limits

    Example:
        >>> amount = new_undefined_amount(PyDecimal("100"))
        >>> result = amount_decimal_div(amount, PyDecimal("4"))
        >>> # result value is 25
    """
    if amount is None:
        raise ValueError("amount cannot be None")

    if divisor == 0:
        raise ZeroDivisionError("cannot divide amount by zero")

    from .decimal_operations import decimal_div

    divisor_decimal = Decimal(value=str(divisor))
    new_value_decimal = decimal_div(amount.value, divisor_decimal)
    new_value_py = PyDecimal(new_value_decimal.value) if new_value_decimal.value else PyDecimal(0)

    return amount_set_value(amount, new_value_py, precision_loss_tolerance)



"""Account v1 package."""

# ===================================================================
# AUTO-GENERATED SECTION - ONLY EDIT BELOW THE CLOSING COMMENT BLOCK
# ===================================================================
# This section is automatically managed by protoc-gen-meshpy.
#
# DO NOT EDIT ANYTHING IN THIS SECTION MANUALLY!
# Your changes will be overwritten during code generation.
#
# To add custom imports and exports, scroll down to the
# "MANUAL SECTION" indicated below.
# ===================================================================

# Generated protobuf imports
from .account_pb2 import (
    Account,
    AccountState,
    Balance,
    InstrumentMetaData,
)
from .service_pb2 import (
    CreateAccountRequest,
    GetAccountByNumberRequest,
    GetAccountRequest,
    ListAccountsRequest,
    ListAccountsResponse,
    OpenAccountRequest,
    OpenAccountResponse,
    SearchAccountsRequest,
    SearchAccountsResponse,
    UpdateAccountRequest,
)

# Generated service imports
from .service_meshpy import (
    AccountService,
    AccountServiceGRPCClient,
    AccountServiceGRPCClientInterface,
)

# ===================================================================
# END OF AUTO-GENERATED SECTION
# ===================================================================
#
# MANUAL SECTION - ADD YOUR CUSTOM IMPORTS AND EXPORTS BELOW
#
# You can safely add your own imports, functions, classes, and exports
# in this section. They will be preserved across code generation.
#
# Example:
#   from my_custom_module import my_function
#
# ===================================================================

# ===================================================================
# MODULE EXPORTS
# ===================================================================
# Combined auto-generated and manual exports
__all__ = [
    # Generated exports
    "Account",
    "AccountService",
    "AccountServiceGRPCClient",
    "AccountServiceGRPCClientInterface",
    "AccountState",
    "Balance",
    "CreateAccountRequest",
    "GetAccountByNumberRequest",
    "GetAccountRequest",
    "InstrumentMetaData",
    "ListAccountsRequest",
    "ListAccountsResponse",
    "OpenAccountRequest",
    "OpenAccountResponse",
    "SearchAccountsRequest",
    "SearchAccountsResponse",
    "UpdateAccountRequest",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/ledger/transaction/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/ledger/transaction/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2
from meshtrade.ledger.transaction.v1 import transaction_state_pb2 as meshtrade_dot_ledger_dot_transaction_dot_v1_dot_transaction__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-meshtrade/ledger/transaction/v1/service.proto\x12\x1fmeshtrade.ledger.transaction.v1\x1a\x1b\x62uf/validate/validate.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\x1a\x37meshtrade/ledger/transaction/v1/transaction_state.proto\"t\n\x1aGetTransactionStateRequest\x12V\n\x04name\x18\x01 \x01(\tBB\xbaH?r:25^transactions/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01\'\xc8\x01\x01R\x04name\"f\n\x1bGetTransactionStateResponse\x12G\n\x05state\x18\x01 \x01(\x0e\x32\x31.meshtrade.ledger.transaction.v1.TransactionStateR\x05state\"x\n\x1eMonitorTransactionStateRequest\x12V\n\x04name\x18\x01 \x01(\tBB\xbaH?r:25^transactions/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01\'\xc8\x01\x01R\x04name\"j\n\x1fMonitorTransactionStateResponse\x12G\n\x05state\x18\x01 \x01(\x0e\x32\x31.meshtrade.ledger.transaction.v1.TransactionStateR\x05state2\x80\x03\n\x12TransactionService\x12\xac\x01\n\x13GetTransactionState\x12;.meshtrade.ledger.transaction.v1.GetTransactionStateRequest\x1a<.meshtrade.ledger.transaction.v1.GetTransactionStateResponse\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x9f\xab\x03\xc1\x9f\xab\x03\xc2\x9f\xab\x03\xc3\x9f\xab\x03\x12\xba\x01\n\x17MonitorTransactionState\x12?.meshtrade.ledger.transaction.v1.MonitorTransactionStateRequest\x1a@.meshtrade.ledger.transaction.v1.MonitorTransactionStateResponse\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x9f\xab\x03\xc1\x9f\xab\x03\xc2\x9f\xab\x03\xc3\x9f\xab\x03\x30\x01\x42j\n&co.meshtrade.api.ledger.transaction.v1Z@github.com/meshtrade/api/go/ledger/transaction/v1;transaction_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.ledger.transaction.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&co.meshtrade.api.ledger.transaction.v1Z@github.com/meshtrade/api/go/ledger/transaction/v1;transaction_v1'
  _globals['_GETTRANSACTIONSTATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETTRANSACTIONSTATEREQUEST'].fields_by_name['name']._serialized_options = b'\272H?r:25^transactions/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001\'\310\001\001'
  _globals['_MONITORTRANSACTIONSTATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_MONITORTRANSACTIONSTATEREQUEST'].fields_by_name['name']._serialized_options = b'\272H?r:25^transactions/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001\'\310\001\001'
  _globals['_TRANSACTIONSERVICE'].methods_by_name['GetTransactionState']._loaded_options = None
  _globals['_TRANSACTIONSERVICE'].methods_by_name['GetTransactionState']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\237\253\003\301\237\253\003\302\237\253\003\303\237\253\003'
  _globals['_TRANSACTIONSERVICE'].methods_by_name['MonitorTransactionState']._loaded_options = None
  _globals['_TRANSACTIONSERVICE'].methods_by_name['MonitorTransactionState']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\237\253\003\301\237\253\003\302\237\253\003\303\237\253\003'
  _globals['_GETTRANSACTIONSTATEREQUEST']._serialized_start=241
  _globals['_GETTRANSACTIONSTATEREQUEST']._serialized_end=357
  _globals['_GETTRANSACTIONSTATERESPONSE']._serialized_start=359
  _globals['_GETTRANSACTIONSTATERESPONSE']._serialized_end=461
  _globals['_MONITORTRANSACTIONSTATEREQUEST']._serialized_start=463
  _globals['_MONITORTRANSACTIONSTATEREQUEST']._serialized_end=583
  _globals['_MONITORTRANSACTIONSTATERESPONSE']._serialized_start=585
  _globals['_MONITORTRANSACTIONSTATERESPONSE']._serialized_end=691
  _globals['_TRANSACTIONSERVICE']._serialized_start=694
  _globals['_TRANSACTIONSERVICE']._serialized_end=1078
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/account_report/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/account_report/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2
from meshtrade.reporting.account_report.v1 import account_report_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3meshtrade/reporting/account_report/v1/service.proto\x12%meshtrade.reporting.account_report.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\x1a:meshtrade/reporting/account_report/v1/account_report.proto\x1a\x1dmeshtrade/type/v1/token.proto\"\xa7\x03\n\x17GetAccountReportRequest\x12\x39\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\tB\x12\xbaH\x0fr\r2\x0b^1[0-9]{6}$R\raccountNumber\x12\x45\n\x0cperiod_start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x0bperiodStart\x12\x41\n\nperiod_end\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\tperiodEnd\x12T\n\x15reporting_asset_token\x18\x04 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenB\x06\xbaH\x03\xc8\x01\x01R\x13reportingAssetToken:q\xbaHn\x1al\n\x18period.chronological.get\x12+period_end must be on or after period_start\x1a#this.period_end > this.period_start\"\xaf\x03\n\x1cGetExcelAccountReportRequest\x12\x39\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\tB\x12\xbaH\x0fr\r2\x0b^1[0-9]{6}$R\raccountNumber\x12\x45\n\x0cperiod_start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x0bperiodStart\x12\x41\n\nperiod_end\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\tperiodEnd\x12T\n\x15reporting_asset_token\x18\x04 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenB\x06\xbaH\x03\xc8\x01\x01R\x13reportingAssetToken:t\xbaHq\x1ao\n\x1aperiod.chronological.excel\x12+period_end must be on or after period_start\x1a$this.period_end >= this.period_start\"B\n\x1dGetExcelAccountReportResponse\x12!\n\x0c\x65xcel_base64\x18\x01 \x01(\tR\x0b\x65xcelBase642\xee\x02\n\x14\x41\x63\x63ountReportService\x12\x9c\x01\n\x10GetAccountReport\x12>.meshtrade.reporting.account_report.v1.GetAccountReportRequest\x1a\x34.meshtrade.reporting.account_report.v1.AccountReport\"\x12\xa0\xb5\x18\x01\xaa\xb5\x18\n\n\x08\x80\x9b\xee\x02\x81\x9b\xee\x02\x12\xb6\x01\n\x15GetExcelAccountReport\x12\x43.meshtrade.reporting.account_report.v1.GetExcelAccountReportRequest\x1a\x44.meshtrade.reporting.account_report.v1.GetExcelAccountReportResponse\"\x12\xa0\xb5\x18\x01\xaa\xb5\x18\n\n\x08\x80\x9b\xee\x02\x81\x9b\xee\x02\x42y\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.account_report.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1'
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['account_number']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['account_number']._serialized_options = b'\272H\017r\r2\013^1[0-9]{6}$'
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['period_start']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['period_start']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['period_end']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['period_end']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['reporting_asset_token']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['reporting_asset_token']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETACCOUNTREPORTREQUEST']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST']._serialized_options = b'\272Hn\032l\n\030period.chronological.get\022+period_end must be on or after period_start\032#this.period_end > this.period_start'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['account_number']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['account_number']._serialized_options = b'\272H\017r\r2\013^1[0-9]{6}$'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['period_start']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['period_start']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['period_end']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['period_end']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['reporting_asset_token']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['reporting_asset_token']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._serialized_options = b'\272Hq\032o\n\032period.chronological.excel\022+period_end must be on or after period_start\032$this.period_end >= this.period_start'
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetAccountReport']._loaded_options = None
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetAccountReport']._serialized_options = b'\240\265\030\001\252\265\030\n\n\010\200\233\356\002\201\233\356\002'
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetExcelAccountReport']._loaded_options = None
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetExcelAccountReport']._serialized_options = b'\240\265\030\001\252\265\030\n\n\010\200\233\356\002\201\233\356\002'
  _globals['_GETACCOUNTREPORTREQUEST']._serialized_start=321
  _globals['_GETACCOUNTREPORTREQUEST']._serialized_end=744
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._serialized_start=747
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._serialized_end=1178
  _globals['_GETEXCELACCOUNTREPORTRESPONSE']._serialized_start=1180
  _globals['_GETEXCELACCOUNTREPORTRESPONSE']._serialized_end=1246
  _globals['_ACCOUNTREPORTSERVICE']._serialized_start=1249
  _globals['_ACCOUNTREPORTSERVICE']._serialized_end=1615
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from meshtrade.type.v1 import amount_pb2 as _amount_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TradingStatementEntry(_message.Message):
    __slots__ = ("transaction_date", "transaction_id", "token_code", "description", "amount", "price", "cost", "balance")
    TRANSACTION_DATE_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    TOKEN_CODE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    COST_FIELD_NUMBER: _ClassVar[int]
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    transaction_date: _timestamp_pb2.Timestamp
    transaction_id: str
    token_code: str
    description: str
    amount: _amount_pb2.Amount
    price: _amount_pb2.Amount
    cost: _amount_pb2.Amount
    balance: _amount_pb2.Amount
    def __init__(self, transaction_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., transaction_id: _Optional[str] = ..., token_code: _Optional[str] = ..., description: _Optional[str] = ..., amount: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., price: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., cost: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., balance: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ...) -> None: ...



"""Token utility functions for Mesh API.

This module provides utility functions for working with Token protobuf messages,
including helper functions for token creation, validation, and formatting.
"""

from .ledger_pb2 import Ledger
from .token_pb2 import Token


def new_undefined_token() -> Token:
    """Create a new Token representing an undefined or placeholder token.

    The undefined token has:
    - Code: "-"
    - Issuer: "-"
    - Ledger: LEDGER_UNSPECIFIED

    This is useful as a sentinel value to represent the absence of a valid token
    or as a placeholder in data structures.

    Returns:
        A Token configured as undefined

    Example:
        >>> token = new_undefined_token()
        >>> token.code
        '-'
        >>> token.issuer
        '-'
        >>> token_is_undefined(token)
        True
    """
    return Token(
        code="-",
        issuer="-",
        ledger=Ledger.LEDGER_UNSPECIFIED,
    )


def token_is_undefined(token: Token | None) -> bool:
    """Check whether this token represents an undefined or placeholder token.

    A token is considered undefined if:
    - The token is None, OR
    - The token has Code == "-" AND Issuer == "-" AND Ledger == LEDGER_UNSPECIFIED

    Args:
        token: Token to check (can be None)

    Returns:
        True if the token is undefined (None or matches undefined pattern), False otherwise

    None Safety:
        Returns True if token is None

    Example:
        >>> token = None
        >>> token_is_undefined(token)
        True
        >>> token = new_undefined_token()
        >>> token_is_undefined(token)
        True
        >>> defined = Token(code="USD", issuer="ISSUER", ledger=Ledger.LEDGER_STELLAR)
        >>> token_is_undefined(defined)
        False
    """
    if token is None:
        return True

    return token.code == "-" and token.issuer == "-" and token.ledger == Ledger.LEDGER_UNSPECIFIED


def token_is_equal_to(token1: Token | None, token2: Token | None) -> bool:
    """Compare two tokens for equality.

    Two tokens are considered equal if and only if all of the following match:
    - Code (asset code)
    - Issuer (asset issuer)
    - Ledger (blockchain/ledger type)

    Args:
        token1: First token to compare (can be None)
        token2: Second token to compare (can be None)

    Returns:
        True if both tokens are equal (including both being None), False otherwise

    None Safety:
        Returns True if both are None, False if only one is None

    Example:
        >>> token1 = Token(code="USD", issuer="ISSUER1", ledger=Ledger.LEDGER_STELLAR)
        >>> token2 = Token(code="USD", issuer="ISSUER1", ledger=Ledger.LEDGER_STELLAR)
        >>> token_is_equal_to(token1, token2)
        True
        >>> token3 = Token(code="EUR", issuer="ISSUER1", ledger=Ledger.LEDGER_STELLAR)
        >>> token_is_equal_to(token1, token3)
        False
        >>> token_is_equal_to(None, None)
        True
    """
    # Handle None cases
    if token1 is None and token2 is None:
        return True
    if token1 is None or token2 is None:
        return False

    return token1.code == token2.code and token1.issuer == token2.issuer and token1.ledger == token2.ledger


def token_pretty_string(token: Token | None) -> str:
    """Return a human-readable string representation of the token.

    Format: "CODE by ISSUER on NETWORK"

    Args:
        token: Token to format (can be None)

    Returns:
        A formatted string describing the token, or "undefined" if None/undefined

    None Safety:
        Returns "undefined" if token is None

    Example:
        >>> token = Token(code="USD", issuer="CIRCLE", ledger=Ledger.LEDGER_STELLAR)
        >>> token_pretty_string(token)
        'USD by CIRCLE on Stellar'
        >>> token_pretty_string(None)
        'undefined'
        >>> token_pretty_string(new_undefined_token())
        'undefined'
    """
    if token is None:
        return "undefined"

    if token_is_undefined(token):
        return "undefined"

    # Import ledger utility for pretty printing
    from .ledger import ledger_to_pretty_string

    return f"{token.code} by {token.issuer} on {ledger_to_pretty_string(token.ledger)}"



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Unit(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNIT_UNSPECIFIED: _ClassVar[Unit]
    UNIT_NULL: _ClassVar[Unit]
    UNIT_NOTE: _ClassVar[Unit]
    UNIT_SHARE: _ClassVar[Unit]
    UNIT_PREFERENCE_SHARE: _ClassVar[Unit]
    UNIT_BOND: _ClassVar[Unit]
    UNIT_BILL: _ClassVar[Unit]
    UNIT_CONTRACT: _ClassVar[Unit]
    UNIT_OPTION: _ClassVar[Unit]
    UNIT_TOKEN: _ClassVar[Unit]
    UNIT_BARREL: _ClassVar[Unit]
    UNIT_GRAM: _ClassVar[Unit]
    UNIT_KILOGRAM: _ClassVar[Unit]
    UNIT_METRIC_TON: _ClassVar[Unit]
    UNIT_OUNCE: _ClassVar[Unit]
    UNIT_HALF_OUNCE: _ClassVar[Unit]
    UNIT_QUARTER_OUNCE: _ClassVar[Unit]
    UNIT_ONE_TENTH_OUNCE: _ClassVar[Unit]
    UNIT_ONE_HUNDREDTH_OUNCE: _ClassVar[Unit]
UNIT_UNSPECIFIED: Unit
UNIT_NULL: Unit
UNIT_NOTE: Unit
UNIT_SHARE: Unit
UNIT_PREFERENCE_SHARE: Unit
UNIT_BOND: Unit
UNIT_BILL: Unit
UNIT_CONTRACT: Unit
UNIT_OPTION: Unit
UNIT_TOKEN: Unit
UNIT_BARREL: Unit
UNIT_GRAM: Unit
UNIT_KILOGRAM: Unit
UNIT_METRIC_TON: Unit
UNIT_OUNCE: Unit
UNIT_HALF_OUNCE: Unit
UNIT_QUARTER_OUNCE: Unit
UNIT_ONE_TENTH_OUNCE: Unit
UNIT_ONE_HUNDREDTH_OUNCE: Unit



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.compliance.client.v1 import client_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2
from meshtrade.compliance.client.v1 import service_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2


class ClientServiceStub(object):
    """Service manages client profiles for compliance and Know Your Customer (KYC)
    purposes.

    The main entity managed by this service is the `Client` resource. A client can
    be a natural person, company, or trust. This service allows you to retrieve
    the compliance profiles for these clients.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateClient = channel.unary_unary(
                '/meshtrade.compliance.client.v1.ClientService/CreateClient',
                request_serializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.CreateClientRequest.SerializeToString,
                response_deserializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2.Client.FromString,
                _registered_method=True)
        self.GetClient = channel.unary_unary(
                '/meshtrade.compliance.client.v1.ClientService/GetClient',
                request_serializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.GetClientRequest.SerializeToString,
                response_deserializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2.Client.FromString,
                _registered_method=True)
        self.ListClients = channel.unary_unary(
                '/meshtrade.compliance.client.v1.ClientService/ListClients',
                request_serializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.ListClientsRequest.SerializeToString,
                response_deserializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.ListClientsResponse.FromString,
                _registered_method=True)


class ClientServiceServicer(object):
    """Service manages client profiles for compliance and Know Your Customer (KYC)
    purposes.

    The main entity managed by this service is the `Client` resource. A client can
    be a natural person, company, or trust. This service allows you to retrieve
    the compliance profiles for these clients.
    """

    def CreateClient(self, request, context):
        """CreateClient creates a single client.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClient(self, request, context):
        """GetClient retrieves a single client's compliance profile by its unique resource name.

        This allows for fetching the complete compliance details of a specific client,
        including all associated information like identification documents, tax residencies,
        and company structures.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListClients(self, request, context):
        """ListClients retrieves a collection of client compliance profiles.

        This method is useful for fetching multiple client records at once.
        Note: This endpoint does not currently support pagination or filtering.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClientServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateClient': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateClient,
                    request_deserializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.CreateClientRequest.FromString,
                    response_serializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2.Client.SerializeToString,
            ),
            'GetClient': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClient,
                    request_deserializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.GetClientRequest.FromString,
                    response_serializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2.Client.SerializeToString,
            ),
            'ListClients': grpc.unary_unary_rpc_method_handler(
                    servicer.ListClients,
                    request_deserializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.ListClientsRequest.FromString,
                    response_serializer=meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.ListClientsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.compliance.client.v1.ClientService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.compliance.client.v1.ClientService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ClientService(object):
    """Service manages client profiles for compliance and Know Your Customer (KYC)
    purposes.

    The main entity managed by this service is the `Client` resource. A client can
    be a natural person, company, or trust. This service allows you to retrieve
    the compliance profiles for these clients.
    """

    @staticmethod
    def CreateClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.compliance.client.v1.ClientService/CreateClient',
            meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.CreateClientRequest.SerializeToString,
            meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2.Client.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.compliance.client.v1.ClientService/GetClient',
            meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.GetClientRequest.SerializeToString,
            meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2.Client.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListClients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.compliance.client.v1.ClientService/ListClients',
            meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.ListClientsRequest.SerializeToString,
            meshtrade_dot_compliance_dot_client_dot_v1_dot_service__pb2.ListClientsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/option/v1/method_type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/option/v1/method_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%meshtrade/option/v1/method_type.proto\x12\x13meshtrade.option.v1\x1a google/protobuf/descriptor.proto*V\n\nMethodType\x12\x1b\n\x17METHOD_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10METHOD_TYPE_READ\x10\x01\x12\x15\n\x11METHOD_TYPE_WRITE\x10\x02:b\n\x0bmethod_type\x12\x1e.google.protobuf.MethodOptions\x18\xd4\x86\x03 \x01(\x0e\x32\x1f.meshtrade.option.v1.MethodTypeR\nmethodTypeBM\n\x1a\x63o.meshtrade.api.option.v1Z/github.com/meshtrade/api/go/option/v1;option_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.option.v1.method_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032co.meshtrade.api.option.v1Z/github.com/meshtrade/api/go/option/v1;option_v1'
  _globals['_METHODTYPE']._serialized_start=96
  _globals['_METHODTYPE']._serialized_end=182
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = ("name", "owner", "email", "roles")
    NAME_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    name: str
    owner: str
    email: str
    roles: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., owner: _Optional[str] = ..., email: _Optional[str] = ..., roles: _Optional[_Iterable[str]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.trading.limit_order.v1 import limit_order_pb2 as meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2
from meshtrade.trading.limit_order.v1 import service_pb2 as meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2


class LimitOrderServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetLimitOrder = channel.unary_unary(
                '/meshtrade.trading.limit_order.v1.LimitOrderService/GetLimitOrder',
                request_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderRequest.SerializeToString,
                response_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
                _registered_method=True)


class LimitOrderServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetLimitOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LimitOrderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetLimitOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLimitOrder,
                    request_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderRequest.FromString,
                    response_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.trading.limit_order.v1.LimitOrderService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.trading.limit_order.v1.LimitOrderService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class LimitOrderService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetLimitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.trading.limit_order.v1.LimitOrderService/GetLimitOrder',
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderRequest.SerializeToString,
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import datetime

from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from meshtrade.iam.role.v1 import role_pb2 as _role_pb2
from meshtrade.option.v1 import method_type_pb2 as _method_type_pb2
from meshtrade.reporting.account_report.v1 import account_report_pb2 as _account_report_pb2
from meshtrade.type.v1 import token_pb2 as _token_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetAccountReportRequest(_message.Message):
    __slots__ = ("account_number", "period_start", "period_end", "reporting_asset_token")
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PERIOD_START_FIELD_NUMBER: _ClassVar[int]
    PERIOD_END_FIELD_NUMBER: _ClassVar[int]
    REPORTING_ASSET_TOKEN_FIELD_NUMBER: _ClassVar[int]
    account_number: str
    period_start: _timestamp_pb2.Timestamp
    period_end: _timestamp_pb2.Timestamp
    reporting_asset_token: _token_pb2.Token
    def __init__(self, account_number: _Optional[str] = ..., period_start: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., period_end: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., reporting_asset_token: _Optional[_Union[_token_pb2.Token, _Mapping]] = ...) -> None: ...

class GetExcelAccountReportRequest(_message.Message):
    __slots__ = ("account_number", "period_start", "period_end", "reporting_asset_token")
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PERIOD_START_FIELD_NUMBER: _ClassVar[int]
    PERIOD_END_FIELD_NUMBER: _ClassVar[int]
    REPORTING_ASSET_TOKEN_FIELD_NUMBER: _ClassVar[int]
    account_number: str
    period_start: _timestamp_pb2.Timestamp
    period_end: _timestamp_pb2.Timestamp
    reporting_asset_token: _token_pb2.Token
    def __init__(self, account_number: _Optional[str] = ..., period_start: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., period_end: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., reporting_asset_token: _Optional[_Union[_token_pb2.Token, _Mapping]] = ...) -> None: ...

class GetExcelAccountReportResponse(_message.Message):
    __slots__ = ("excel_base64",)
    EXCEL_BASE64_FIELD_NUMBER: _ClassVar[int]
    excel_base64: str
    def __init__(self, excel_base64: _Optional[str] = ...) -> None: ...



import datetime

from meshtrade.type.v1 import token_pb2 as _token_pb2
from meshtrade.type.v1 import amount_pb2 as _amount_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IncomeNarrative(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    INCOME_NARRATIVE_UNSPECIFIED: _ClassVar[IncomeNarrative]
    INCOME_NARRATIVE_YIELD: _ClassVar[IncomeNarrative]
    INCOME_NARRATIVE_DIVIDEND: _ClassVar[IncomeNarrative]
    INCOME_NARRATIVE_INTEREST: _ClassVar[IncomeNarrative]
    INCOME_NARRATIVE_PRINCIPAL: _ClassVar[IncomeNarrative]
    INCOME_NARRATIVE_DISTRIBUTION: _ClassVar[IncomeNarrative]
    INCOME_NARRATIVE_PROFIT_DISTRIBUTION: _ClassVar[IncomeNarrative]
INCOME_NARRATIVE_UNSPECIFIED: IncomeNarrative
INCOME_NARRATIVE_YIELD: IncomeNarrative
INCOME_NARRATIVE_DIVIDEND: IncomeNarrative
INCOME_NARRATIVE_INTEREST: IncomeNarrative
INCOME_NARRATIVE_PRINCIPAL: IncomeNarrative
INCOME_NARRATIVE_DISTRIBUTION: IncomeNarrative
INCOME_NARRATIVE_PROFIT_DISTRIBUTION: IncomeNarrative

class IncomeEntry(_message.Message):
    __slots__ = ("asset_name", "token", "date", "description", "narrative", "amount", "reported_currency_value")
    ASSET_NAME_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    DATE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    NARRATIVE_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    REPORTED_CURRENCY_VALUE_FIELD_NUMBER: _ClassVar[int]
    asset_name: str
    token: _token_pb2.Token
    date: _timestamp_pb2.Timestamp
    description: str
    narrative: IncomeNarrative
    amount: _amount_pb2.Amount
    reported_currency_value: _amount_pb2.Amount
    def __init__(self, asset_name: _Optional[str] = ..., token: _Optional[_Union[_token_pb2.Token, _Mapping]] = ..., date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., description: _Optional[str] = ..., narrative: _Optional[_Union[IncomeNarrative, str]] = ..., amount: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., reported_currency_value: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.iam.group.v1 import group_pb2 as meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2
from meshtrade.iam.group.v1 import service_pb2 as meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2


class GroupServiceStub(object):
    """
    GroupService manages organizational group hierarchy and lifecycle operations.

    Groups are the fundamental multi-tenancy units in Mesh that own resources,
    define permission boundaries, and enable hierarchical access control.
    Each group can own sub-groups, users, API users, and platform resources,
    forming tree structures for inherited permissions and resource isolation.

    All operations are scoped to the authenticated group's hierarchy and
    require appropriate IAM domain permissions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateGroup = channel.unary_unary(
                '/meshtrade.iam.group.v1.GroupService/CreateGroup',
                request_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.CreateGroupRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2.Group.FromString,
                _registered_method=True)
        self.UpdateGroup = channel.unary_unary(
                '/meshtrade.iam.group.v1.GroupService/UpdateGroup',
                request_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.UpdateGroupRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2.Group.FromString,
                _registered_method=True)
        self.ListGroups = channel.unary_unary(
                '/meshtrade.iam.group.v1.GroupService/ListGroups',
                request_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.ListGroupsRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.ListGroupsResponse.FromString,
                _registered_method=True)
        self.SearchGroups = channel.unary_unary(
                '/meshtrade.iam.group.v1.GroupService/SearchGroups',
                request_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.SearchGroupsRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.SearchGroupsResponse.FromString,
                _registered_method=True)
        self.GetGroup = channel.unary_unary(
                '/meshtrade.iam.group.v1.GroupService/GetGroup',
                request_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.GetGroupRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2.Group.FromString,
                _registered_method=True)


class GroupServiceServicer(object):
    """
    GroupService manages organizational group hierarchy and lifecycle operations.

    Groups are the fundamental multi-tenancy units in Mesh that own resources,
    define permission boundaries, and enable hierarchical access control.
    Each group can own sub-groups, users, API users, and platform resources,
    forming tree structures for inherited permissions and resource isolation.

    All operations are scoped to the authenticated group's hierarchy and
    require appropriate IAM domain permissions.
    """

    def CreateGroup(self, request, context):
        """
        Creates a new child group within the authenticated group's hierarchy.

        The new group inherits access from its parent and becomes part of the
        organizational structure. Group ownership must match the executing context.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateGroup(self, request, context):
        """
        Updates an existing group's display name and description metadata.

        Only mutable fields can be modified while preserving the group's
        identity and ownership within the hierarchy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListGroups(self, request, context):
        """
        Retrieves all groups within the authenticated group's hierarchical scope.

        Returns the complete organizational structure accessible to the executing
        context, including the root group and all descendant groups.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchGroups(self, request, context):
        """
        Searches groups using flexible text criteria within the hierarchy.

        Performs case-insensitive substring matching on display names and
        descriptions using OR logic across search terms.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroup(self, request, context):
        """
        Retrieves a specific group by its resource identifier within the hierarchy.

        Provides access to a single group's complete metadata and organizational
        context if accessible within the executing group's scope.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GroupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGroup,
                    request_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.CreateGroupRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2.Group.SerializeToString,
            ),
            'UpdateGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateGroup,
                    request_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.UpdateGroupRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2.Group.SerializeToString,
            ),
            'ListGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListGroups,
                    request_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.ListGroupsRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.ListGroupsResponse.SerializeToString,
            ),
            'SearchGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchGroups,
                    request_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.SearchGroupsRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.SearchGroupsResponse.SerializeToString,
            ),
            'GetGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroup,
                    request_deserializer=meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.GetGroupRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2.Group.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.iam.group.v1.GroupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.iam.group.v1.GroupService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class GroupService(object):
    """
    GroupService manages organizational group hierarchy and lifecycle operations.

    Groups are the fundamental multi-tenancy units in Mesh that own resources,
    define permission boundaries, and enable hierarchical access control.
    Each group can own sub-groups, users, API users, and platform resources,
    forming tree structures for inherited permissions and resource isolation.

    All operations are scoped to the authenticated group's hierarchy and
    require appropriate IAM domain permissions.
    """

    @staticmethod
    def CreateGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.group.v1.GroupService/CreateGroup',
            meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.CreateGroupRequest.SerializeToString,
            meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2.Group.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.group.v1.GroupService/UpdateGroup',
            meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.UpdateGroupRequest.SerializeToString,
            meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2.Group.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.group.v1.GroupService/ListGroups',
            meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.ListGroupsRequest.SerializeToString,
            meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.ListGroupsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.group.v1.GroupService/SearchGroups',
            meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.SearchGroupsRequest.SerializeToString,
            meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.SearchGroupsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.group.v1.GroupService/GetGroup',
            meshtrade_dot_iam_dot_group_dot_v1_dot_service__pb2.GetGroupRequest.SerializeToString,
            meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2.Group.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/user/v1/user.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/user/v1/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n meshtrade/iam/user/v1/user.proto\x12\x15meshtrade.iam.user.v1\x1a\x1b\x62uf/validate/validate.proto\"\xa6\x03\n\x04User\x12\xba\x01\n\x04name\x18\x01 \x01(\tB\xa5\x01\xbaH\xa1\x01\xba\x01\x9d\x01\n\x14name.format.optional\x12\x32name must be empty or in the format users/{ULIDv2}\x1aQsize(this) == 0 || this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x04name\x12R\n\x05owner\x18\x02 \x01(\tB<\xbaH9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x05owner\x12 \n\x05\x65mail\x18\x03 \x01(\tB\n\xbaH\x07r\x02`\x01\xc8\x01\x01R\x05\x65mail\x12k\n\x05roles\x18\x04 \x03(\tBU\xbaHR\x92\x01O\"MrK\x10/\x18\x30\x32\x45^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$R\x05rolesBO\n\x1c\x63o.meshtrade.api.iam.user.v1Z/github.com/meshtrade/api/go/iam/user/v1;user_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.user.v1.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034co.meshtrade.api.iam.user.v1Z/github.com/meshtrade/api/go/iam/user/v1;user_v1'
  _globals['_USER'].fields_by_name['name']._loaded_options = None
  _globals['_USER'].fields_by_name['name']._serialized_options = b'\272H\241\001\272\001\235\001\n\024name.format.optional\0222name must be empty or in the format users/{ULIDv2}\032Qsize(this) == 0 || this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_USER'].fields_by_name['owner']._loaded_options = None
  _globals['_USER'].fields_by_name['owner']._serialized_options = b'\272H9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_USER'].fields_by_name['email']._loaded_options = None
  _globals['_USER'].fields_by_name['email']._serialized_options = b'\272H\007r\002`\001\310\001\001'
  _globals['_USER'].fields_by_name['roles']._loaded_options = None
  _globals['_USER'].fields_by_name['roles']._serialized_options = b'\272HR\222\001O\"MrK\020/\03002E^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$'
  _globals['_USER']._serialized_start=89
  _globals['_USER']._serialized_end=511
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from meshtrade.type.v1 import token_pb2 as _token_pb2
from meshtrade.type.v1 import address_pb2 as _address_pb2
from meshtrade.reporting.account_report.v1 import fee_entry_pb2 as _fee_entry_pb2
from meshtrade.reporting.account_report.v1 import income_entry_pb2 as _income_entry_pb2
from meshtrade.reporting.account_report.v1 import trading_statement_entry_pb2 as _trading_statement_entry_pb2
from meshtrade.reporting.account_report.v1 import disclaimer_pb2 as _disclaimer_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AccountReport(_message.Message):
    __slots__ = ("income_entries", "fee_entries", "trading_statement_entries", "reporting_currency", "period", "generation_date", "account_number", "disclaimers", "client_address", "client_name", "copyright")
    class Period(_message.Message):
        __slots__ = ("period_start", "period_end")
        PERIOD_START_FIELD_NUMBER: _ClassVar[int]
        PERIOD_END_FIELD_NUMBER: _ClassVar[int]
        period_start: _timestamp_pb2.Timestamp
        period_end: _timestamp_pb2.Timestamp
        def __init__(self, period_start: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., period_end: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    INCOME_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    FEE_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    TRADING_STATEMENT_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    REPORTING_CURRENCY_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    GENERATION_DATE_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    DISCLAIMERS_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CLIENT_NAME_FIELD_NUMBER: _ClassVar[int]
    COPYRIGHT_FIELD_NUMBER: _ClassVar[int]
    income_entries: _containers.RepeatedCompositeFieldContainer[_income_entry_pb2.IncomeEntry]
    fee_entries: _containers.RepeatedCompositeFieldContainer[_fee_entry_pb2.FeeEntry]
    trading_statement_entries: _containers.RepeatedCompositeFieldContainer[_trading_statement_entry_pb2.TradingStatementEntry]
    reporting_currency: _token_pb2.Token
    period: AccountReport.Period
    generation_date: _timestamp_pb2.Timestamp
    account_number: str
    disclaimers: _containers.RepeatedCompositeFieldContainer[_disclaimer_pb2.Disclaimer]
    client_address: _address_pb2.Address
    client_name: str
    copyright: str
    def __init__(self, income_entries: _Optional[_Iterable[_Union[_income_entry_pb2.IncomeEntry, _Mapping]]] = ..., fee_entries: _Optional[_Iterable[_Union[_fee_entry_pb2.FeeEntry, _Mapping]]] = ..., trading_statement_entries: _Optional[_Iterable[_Union[_trading_statement_entry_pb2.TradingStatementEntry, _Mapping]]] = ..., reporting_currency: _Optional[_Union[_token_pb2.Token, _Mapping]] = ..., period: _Optional[_Union[AccountReport.Period, _Mapping]] = ..., generation_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., account_number: _Optional[str] = ..., disclaimers: _Optional[_Iterable[_Union[_disclaimer_pb2.Disclaimer, _Mapping]]] = ..., client_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., client_name: _Optional[str] = ..., copyright: _Optional[str] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from meshtrade.iam.group.v1 import group_pb2 as _group_pb2
from meshtrade.iam.role.v1 import role_pb2 as _role_pb2
from meshtrade.option.v1 import method_type_pb2 as _method_type_pb2
from meshtrade.type.v1 import sorting_pb2 as _sorting_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateGroupRequest(_message.Message):
    __slots__ = ("group",)
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    def __init__(self, group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...

class UpdateGroupRequest(_message.Message):
    __slots__ = ("group",)
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    def __init__(self, group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...

class ListGroupsRequest(_message.Message):
    __slots__ = ("sorting",)
    class Sorting(_message.Message):
        __slots__ = ("field", "order")
        FIELD_FIELD_NUMBER: _ClassVar[int]
        ORDER_FIELD_NUMBER: _ClassVar[int]
        field: str
        order: _sorting_pb2.SortingOrder
        def __init__(self, field: _Optional[str] = ..., order: _Optional[_Union[_sorting_pb2.SortingOrder, str]] = ...) -> None: ...
    SORTING_FIELD_NUMBER: _ClassVar[int]
    sorting: ListGroupsRequest.Sorting
    def __init__(self, sorting: _Optional[_Union[ListGroupsRequest.Sorting, _Mapping]] = ...) -> None: ...

class ListGroupsResponse(_message.Message):
    __slots__ = ("groups",)
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[_group_pb2.Group]
    def __init__(self, groups: _Optional[_Iterable[_Union[_group_pb2.Group, _Mapping]]] = ...) -> None: ...

class SearchGroupsRequest(_message.Message):
    __slots__ = ("display_name", "description", "sorting")
    class Sorting(_message.Message):
        __slots__ = ("field", "order")
        FIELD_FIELD_NUMBER: _ClassVar[int]
        ORDER_FIELD_NUMBER: _ClassVar[int]
        field: str
        order: _sorting_pb2.SortingOrder
        def __init__(self, field: _Optional[str] = ..., order: _Optional[_Union[_sorting_pb2.SortingOrder, str]] = ...) -> None: ...
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SORTING_FIELD_NUMBER: _ClassVar[int]
    display_name: str
    description: str
    sorting: SearchGroupsRequest.Sorting
    def __init__(self, display_name: _Optional[str] = ..., description: _Optional[str] = ..., sorting: _Optional[_Union[SearchGroupsRequest.Sorting, _Mapping]] = ...) -> None: ...

class SearchGroupsResponse(_message.Message):
    __slots__ = ("groups",)
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[_group_pb2.Group]
    def __init__(self, groups: _Optional[_Iterable[_Union[_group_pb2.Group, _Mapping]]] = ...) -> None: ...

class GetGroupRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.compliance.client.v1 import client_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,meshtrade/compliance/client/v1/service.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\x1a+meshtrade/compliance/client/v1/client.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\"e\n\x10GetClientRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\xbaH:r520^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x04name\"]\n\x13\x43reateClientRequest\x12\x46\n\x06\x63lient\x18\x01 \x01(\x0b\x32&.meshtrade.compliance.client.v1.ClientB\x06\xbaH\x03\xc8\x01\x01R\x06\x63lient\"\x14\n\x12ListClientsRequest\"W\n\x13ListClientsResponse\x12@\n\x07\x63lients\x18\x01 \x03(\x0b\x32&.meshtrade.compliance.client.v1.ClientR\x07\x63lients2\x9e\x03\n\rClientService\x12}\n\x0c\x43reateClient\x12\x33.meshtrade.compliance.client.v1.CreateClientRequest\x1a&.meshtrade.compliance.client.v1.Client\"\x10\xa0\xb5\x18\x02\xaa\xb5\x18\x08\n\x06\x80\x89z\x82\x89z\x12}\n\tGetClient\x12\x30.meshtrade.compliance.client.v1.GetClientRequest\x1a&.meshtrade.compliance.client.v1.Client\"\x16\xa0\xb5\x18\x01\xaa\xb5\x18\x0e\n\x0c\x80\x89z\x81\x89z\x82\x89z\x83\x89z\x12\x8e\x01\n\x0bListClients\x12\x32.meshtrade.compliance.client.v1.ListClientsRequest\x1a\x33.meshtrade.compliance.client.v1.ListClientsResponse\"\x16\xa0\xb5\x18\x01\xaa\xb5\x18\x0e\n\x0c\x80\x89z\x81\x89z\x82\x89z\x83\x89zBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_GETCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\272H:r520^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_CREATECLIENTREQUEST'].fields_by_name['client']._loaded_options = None
  _globals['_CREATECLIENTREQUEST'].fields_by_name['client']._serialized_options = b'\272H\003\310\001\001'
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._serialized_options = b'\240\265\030\002\252\265\030\010\n\006\200\211z\202\211z'
  _globals['_CLIENTSERVICE'].methods_by_name['GetClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['GetClient']._serialized_options = b'\240\265\030\001\252\265\030\016\n\014\200\211z\201\211z\202\211z\203\211z'
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._serialized_options = b'\240\265\030\001\252\265\030\016\n\014\200\211z\201\211z\202\211z\203\211z'
  _globals['_GETCLIENTREQUEST']._serialized_start=227
  _globals['_GETCLIENTREQUEST']._serialized_end=328
  _globals['_CREATECLIENTREQUEST']._serialized_start=330
  _globals['_CREATECLIENTREQUEST']._serialized_end=423
  _globals['_LISTCLIENTSREQUEST']._serialized_start=425
  _globals['_LISTCLIENTSREQUEST']._serialized_end=445
  _globals['_LISTCLIENTSRESPONSE']._serialized_start=447
  _globals['_LISTCLIENTSRESPONSE']._serialized_end=534
  _globals['_CLIENTSERVICE']._serialized_start=537
  _globals['_CLIENTSERVICE']._serialized_end=951
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class VerificationStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VERIFICATION_STATUS_UNSPECIFIED: _ClassVar[VerificationStatus]
    VERIFICATION_STATUS_NOT_STARTED: _ClassVar[VerificationStatus]
    VERIFICATION_STATUS_PENDING: _ClassVar[VerificationStatus]
    VERIFICATION_STATUS_VERIFIED: _ClassVar[VerificationStatus]
    VERIFICATION_STATUS_FAILED: _ClassVar[VerificationStatus]
VERIFICATION_STATUS_UNSPECIFIED: VerificationStatus
VERIFICATION_STATUS_NOT_STARTED: VerificationStatus
VERIFICATION_STATUS_PENDING: VerificationStatus
VERIFICATION_STATUS_VERIFIED: VerificationStatus
VERIFICATION_STATUS_FAILED: VerificationStatus



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/studio/instrument/v1/unit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/studio/instrument/v1/unit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)meshtrade/studio/instrument/v1/unit.proto\x12\x1emeshtrade.studio.instrument.v1*\xf4\x02\n\x04Unit\x12\x14\n\x10UNIT_UNSPECIFIED\x10\x00\x12\r\n\tUNIT_NULL\x10\x01\x12\r\n\tUNIT_NOTE\x10\x02\x12\x0e\n\nUNIT_SHARE\x10\x03\x12\x19\n\x15UNIT_PREFERENCE_SHARE\x10\x04\x12\r\n\tUNIT_BOND\x10\x05\x12\r\n\tUNIT_BILL\x10\x06\x12\x11\n\rUNIT_CONTRACT\x10\x07\x12\x0f\n\x0bUNIT_OPTION\x10\x08\x12\x0e\n\nUNIT_TOKEN\x10\t\x12\x0f\n\x0bUNIT_BARREL\x10\n\x12\r\n\tUNIT_GRAM\x10\x0b\x12\x11\n\rUNIT_KILOGRAM\x10\x0c\x12\x13\n\x0fUNIT_METRIC_TON\x10\r\x12\x0e\n\nUNIT_OUNCE\x10\x0e\x12\x13\n\x0fUNIT_HALF_OUNCE\x10\x0f\x12\x16\n\x12UNIT_QUARTER_OUNCE\x10\x10\x12\x18\n\x14UNIT_ONE_TENTH_OUNCE\x10\x11\x12\x1c\n\x18UNIT_ONE_HUNDREDTH_OUNCE\x10\x12\x42g\n%co.meshtrade.api.studio.instrument.v1Z>github.com/meshtrade/api/go/studio/instrument/v1;instrument_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.studio.instrument.v1.unit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.studio.instrument.v1Z>github.com/meshtrade/api/go/studio/instrument/v1;instrument_v1'
  _globals['_UNIT']._serialized_start=78
  _globals['_UNIT']._serialized_end=450
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IndustryClassification(_message.Message):
    __slots__ = ("sector_code", "sector_name", "industry_group_code", "industry_group_name", "industry_code", "industry_name", "sub_industry_code", "sub_industry_name")
    SECTOR_CODE_FIELD_NUMBER: _ClassVar[int]
    SECTOR_NAME_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_GROUP_CODE_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_NAME_FIELD_NUMBER: _ClassVar[int]
    SUB_INDUSTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    SUB_INDUSTRY_NAME_FIELD_NUMBER: _ClassVar[int]
    sector_code: str
    sector_name: str
    industry_group_code: str
    industry_group_name: str
    industry_code: str
    industry_name: str
    sub_industry_code: str
    sub_industry_name: str
    def __init__(self, sector_code: _Optional[str] = ..., sector_name: _Optional[str] = ..., industry_group_code: _Optional[str] = ..., industry_group_name: _Optional[str] = ..., industry_code: _Optional[str] = ..., industry_name: _Optional[str] = ..., sub_industry_code: _Optional[str] = ..., sub_industry_name: _Optional[str] = ...) -> None: ...
